@@ -434,5 +434,23 @@ class LearningAccessor(BaseAccessor):
 
 
 
+	def batch_predict(self, obj):
+		"""
+		Same as :code:`predict(self, obj)`, but more memory friendly.
+		"""
+		n = obj.shape[0]
+		max_n = 100000
+		res = []
+		i = 0
+		while i < n:
+			res +=[self.predict(obj.iloc[i:i+max_n])]
+			i += max_n
+
+		res = pd.concat(res, axis=0) if len(res) > 1 else res[0]
+		return res
+
+
+
+
 
 
